@@ -1,9 +1,5 @@
-from pydantic import BaseModel, validator
 from datetime import date, timedelta
-from typing import Optional, List
-from base.models.mixins import DurationMixin
-from base.models.utils import makeList, Duration
-from dateutil.parser import parse, ParserError
+from typing import List
 from base.models.employmentbase import EmploymentBase
 
 
@@ -16,6 +12,9 @@ class EmploymentHistory:
                     f"{employment_list} is not a list of EmploymentBase objects"
                 )
 
+    # These properties are usually used to do assessment
+    
+    # these properties are usually used to do word doc automation
     @property
     def initial_start_date(self):
         return min([emp.start_date for emp in self.employment_list])
