@@ -273,10 +273,10 @@ positive_int_include_zero = {
 }
 positive_int_decimal = {
     "validate": "decimal",
-    "criteria": ">",
+    "criteria": ">=",
     "value": 0,
     "input_title": "请输入整数或小数:",
-    "input_message": "必须是大于0",
+    "input_message": "必须是大于等于0",
 }
 
 int_decimal = {
@@ -646,7 +646,7 @@ validation = {
         "bcpnp_qualified": yes_no,
         "ee_qualified": yes_no,
         "employment_certificate": yes_no,
-        "work_under_status":workpermit_type
+        "work_under_status": workpermit_type,
     },
     "table-canadarelative": {
         "province": canada_provinces,
@@ -754,6 +754,8 @@ validation = {
         "room_cost": positive_int_decimal,
         "other_cost": positive_int_decimal,
         "fund_available": positive_int_decimal,
+        "dual_intent": yes_no,
+        "refused_case": yes_no,
     },
     "info-vrincanada": {
         "application_purpose": vr_application_purpose,
